@@ -46,9 +46,10 @@ use App::Dochazka::REST::ACL qw(
     acl_check_is_me 
     acl_check_is_my_report 
 );
-use App::Dochazka::REST::ConnBank qw( conn_status );
+use App::Dochazka::REST::ConnBank qw( $dbix_conn conn_status );
 use App::Dochazka::REST::LDAP qw( populate_employee );
 use App::Dochazka::REST::Model::Activity;
+use App::Dochazka::REST::Model::Component qw( get_all_components );
 use App::Dochazka::REST::Model::Employee qw( 
     list_employees_by_priv 
     noof_employees_by_priv 
@@ -79,6 +80,7 @@ use App::Dochazka::REST::ResourceDefs;
 use App::Dochazka::REST::Shared qw( :ALL );  # all the shared_* functions
 use App::Dochazka::REST::Util::Holiday qw( holidays_in_daterange );
 use Data::Dumper;
+use File::Path qw( mkpath rmtree );
 use Module::Runtime qw( use_module );
 use Params::Validate qw( :all );
 use Try::Tiny;
@@ -123,7 +125,44 @@ my %iue_dispatch = (
 
 =cut
 
-=head2 Router initialization method
+=head2 init
+
+This function is called by C<bin/mrest>.
+
+=cut
+
+sub init {
+    $log->debug("Entering " . __PACKAGE__. "::init");
+    App::Dochazka::REST::ConnBank::init_singleton();
+
+    # reset Mason state directory
+    my $statedir = $site->DOCHAZKA_STATE_DIR;
+    die "OUCH!!! DOCHAZKA_STATE_DIR site parameter not defined!" unless $statedir;
+    die "OUCH!!! DOCHAZKA_STATE_DIR is not readable by me!" unless -R $statedir;
+    die "OUCH!!! DOCHAZKA_STATE_DIR is not writable by me!" unless -W $statedir;
+    die "OUCH!!! DOCHAZKA_STATE_DIR is not executable by me!" unless -X $statedir;
+    my $masondir = File::Spec->catfile( $statedir, 'Mason' );
+    $log->debug( "Mason directory is $masondir" );
+    rmtree( $masondir );
+    mkpath( $masondir, 0, 0750 );
+
+    # get Mason components from database and write them to filesystem
+    my $status = get_all_components( $dbix_conn );
+    if ( $status->ok and $status->code eq 'DISPATCH_RECORDS_FOUND' ) {
+        foreach my $comp ( @{ $status->payload } ) {
+            my ( undef, $dirspec, $filespec ) = File::Spec->splitpath( $comp->path );
+            my $dirspec = File::Spec->catfile( $masondir, $dirspec );
+            mkpath( $dirspec, 0, 0750 );
+            my $filespec = File::Spec->catfile( $dirspec, $filespec );
+            open(my $fh, '>', $filespec) or die "Could not open file '$filespec' $!";
+            print $fh $comp->source;
+            close $fh
+        }
+    }
+}
+
+
+=head2 init_router
 
 The "router" (i.e., L<Path::Router> instance) is initialized when the first
 request comes in, as a first step before any processing of the request takes
@@ -131,9 +170,6 @@ place.
 
 This happens when L<Web::MREST::Resource> calls the C<init_router> method.
 
-
-=head3 init_router
-
 L<App::Dochazka::REST> implements its own C<init_router> method, overriding the
 default one in L<Web::MREST::InitRouter>.
 
@@ -766,6 +802,26 @@ sub handler_put_activity_code {
 =head2 Component handlers
 
 
+=head3 handler_get_component_all
+
+Handler for 'GET component/all'
+
+=cut
+
+sub handler_get_component_all {
+    my ( $self, $pass ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ . "::handler_get_component_all" );
+
+    # first pass
+    return 1 if $pass == 1 ;
+
+    # second pass
+    return App::Dochazka::REST::Model::Component::get_all_components( 
+        $self->context->{'dbix_conn'}, 
+    );
+}
+
+
 =head3 handler_post_component_cid
 
 Handler for 'POST component/cid' resource.
@@ -869,94 +925,6 @@ sub handler_component_cid {
 }
 
 
-=head3 handler_get_component_path
-
-Handler for the 'GET component/path/:path' resource.
-
-=cut
-
-sub handler_get_component_path {
-    my ( $self, $pass ) = @_;
-    $log->debug( "Entering " . __PACKAGE__ . "::handler_get_component_path" ); 
-
-    my $context = $self->context;
-
-    # first pass
-    if ( $pass == 1 ) {
-        my $comp = shared_first_pass_lookup( $self, 'path', $context->{'mapping'}->{'path'} );
-        return 0 unless $comp;
-        $context->{'stashed_component_object'} = $comp;
-        return 1;
-    }
-
-    # second pass
-    return $CELL->status_ok( 'DISPATCH_COMPONENT_FOUND', 
-        payload => $context->{'stashed_component_object'}
-    );
-}
-
-
-=head3 handler_delete_component_path
-
-Handler for the 'DELETE component/path/:path' resource.
-
-=cut
-
-sub handler_delete_component_path {
-    my ( $self, $pass ) = @_;
-    $log->debug( "Entering " . __PACKAGE__ . "::handler_delete_component_path" ); 
-
-    my $context = $self->context;
-
-    # first pass
-    if ( $pass == 1 ) {
-        my $comp = shared_first_pass_lookup( $self, 'path', $context->{'mapping'}->{'path'} );
-        return 0 unless $comp;
-        $context->{'stashed_component_object'} = $comp;
-        return 1;
-    }
-
-    # second pass
-    return $context->{'stashed_component_object'}->delete( $context );
-}
-
-
-=head3 handler_put_component_path
-
-Handler for the 'PUT component/path/:path' resource.
-
-=cut
-
-sub handler_put_component_path {
-    my ( $self, $pass ) = @_;
-    $log->debug( "Entering " . __PACKAGE__ . "::handler_put_component_path" ); 
-
-    my $context = $self->context;
-
-    # first pass
-    return 1 if ( $pass == 1 );
-
-    # second pass
-
-    # - create or modify?
-    my $path = $context->{'mapping'}->{'path'};
-    my $entity = $context->{'request_entity'};
-    if ( ! defined($entity) ) {
-        $self->mrest_declare_status( 'code' => 400, 'explanation' => 'Missing request entity' );
-        return $fail;
-    }
-    my $comp = shared_first_pass_lookup( $self, 'path', $path );
-    $self->nullify_declared_status;
-
-    # - perform insert/update operation
-    if ( $comp ) {
-        return shared_update_component( $self, $comp, $entity );
-    } else {
-        return shared_insert_component( $self, $path, $entity );
-    }
-}
-
-
 
 =head2 Employee handlers
 
